OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan niet schrijven naar de \"config\" directory!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Dit kan opgelost worden door de config map op de webserver schrijfrechten te geven.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Maar, als je liever config.php alleen-lezen wilt houden, stel dan de optie \"config_is_read_only\" in op true.",
    "See %s" : "Zie %s",
    "Sample configuration detected" : "Voorbeeld configuratie gevonden",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Er is gedetecteerd dat de voorbeeld configuratie is gekopieerd. Dit kan je installatie beschadigen en wordt dan ook niet ondersteund. Lees de documentatie voordat je wijzigingen aan config.php doorvoert",
    "The page could not be found on the server." : "Deze pagina kon niet gevonden worden op de server",
    "%s email verification" : "%s e-mail verificatie",
    "Email verification" : "E-mail verificatie",
    "Click the following button to confirm your email." : "Klik op de knop om je e-mail te bevestigen.",
    "Click the following link to confirm your email." : "Klik op de volgende link om je e-mail te bevestigen.",
    "Confirm your email" : "Bevestig je e-mailadres",
    "Other activities" : "Andere activiteiten",
    "%1$s and %2$s" : "%1$s en %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s en %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s en %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s en %5$s",
    "Enterprise bundle" : "Zakelijke bundel",
    "Groupware bundle" : "Groupware bundel",
    "Hub bundle" : "Hub bundel",
    "Social sharing bundle" : "Sociaal delen bundel",
    "PHP %s or higher is required." : "PHP %s of hoger vereist.",
    "PHP with a version lower than %s is required." : "PHP met een versie lager dan %s is vereist.",
    "%sbit or higher PHP required." : "%sbit of hogere PHP versie vereist.",
    "The following architectures are supported: %s" : "Ondersteunde architecturen: %s",
    "The following databases are supported: %s" : "De volgende databases worden ondersteund: %s",
    "The command line tool %s could not be found" : "Commandoregel tool %s is niet gevonden",
    "The library %s is not available." : "Library %s is niet beschikbaar.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Library %1$s met een versienummer hoger dan %2$s is vereist - beschikbare versie %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Library %1$s met een versienummer lager dan %2$s is vereist - beschikbare versie %3$s.",
    "The following platforms are supported: %s" : "De volgende platforms worden ondersteund: %s",
    "Server version %s or higher is required." : "Serverversie %s of hoger vereist.",
    "Server version %s or lower is required." : "Serverversie %s of lager vereist.",
    "Wiping of device %s has started" : "Leegmaken van toestel %sis gestart",
    "Wiping of device »%s« has started" : "Leegmaken van toestel  \"%s\" is gestart",
    "»%s« started remote wipe" : "\"%s\" startte leegmaken op afstand",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Toestel of applicatie \"%s\" heeft leegmaken op afstand gestart. Je ontvangt een ander bericht als het proces is voltooid",
    "Wiping of device %s has finished" : "Leegmaken van toestel %s is voltooid",
    "Wiping of device »%s« has finished" : "Leegmaken van toestel \"%s\" is voltooid",
    "»%s« finished remote wipe" : "\"%s\" voltooide schoonmaken op afstand",
    "Device or application »%s« has finished the remote wipe process." : "Toestel of applicatie \"%s\" heeft het schoonmaken op afstand voltooid.",
    "Remote wipe started" : "Leegmaken op afstand gestart",
    "A remote wipe was started on device %s" : "Leegmaken op afstand gestart op toestel %s",
    "Remote wipe finished" : "Leegmaken op afstand beëindigd",
    "The remote wipe on %s has finished" : "Leegmaken op afstand van %s is voltooid",
    "Authentication" : "Authenticatie",
    "Unknown filetype" : "Onbekend bestandsformaat",
    "Invalid image" : "Ongeldige afbeelding",
    "Avatar image is not square" : "Avatar afbeelding is niet vierkant",
    "Files" : "Bestanden",
    "View profile" : "Bekijk profiel",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "Local time: %s" : "Lokale tijd: %s",
    "today" : "vandaag",
    "tomorrow" : "morgen",
    "yesterday" : "gisteren",
    "_in %n day_::_in %n days_" : ["over %n dag","over %n dagen"],
    "_%n day ago_::_%n days ago_" : ["%n dag geleden","%n dagen geleden"],
    "next month" : "volgende maand",
    "last month" : "vorige maand",
    "_in %n month_::_in %n months_" : ["over %n maand","over %n maanden"],
    "_%n month ago_::_%n months ago_" : ["%n maand geleden","%n maanden geleden"],
    "next year" : "volgend jaar",
    "last year" : "vorig jaar",
    "_in %n year_::_in %n years_" : ["over %n jaar","over %n jaar"],
    "_%n year ago_::_%n years ago_" : ["%n jaar geleden","%n jaren geleden"],
    "_in %n hour_::_in %n hours_" : ["over %n uur","over %n uur"],
    "_%n hour ago_::_%n hours ago_" : ["%n uur geleden","%n uur geleden"],
    "_in %n minute_::_in %n minutes_" : ["over %n minuut","over %n minuten"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuut geleden","%n minuten geleden"],
    "in a few seconds" : "over een paar seconden",
    "seconds ago" : "seconden geleden",
    "Empty file" : "Leeg bestand",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met ID: %s bestaat niet. Schakel die in binnen de app-instellingen of neem contact op met je beheerder.",
    "Dot files are not allowed" : "Punt-bestanden zijn niet toegestaan",
    "%1$s (renamed)" : "%1$s (hernoemd)",
    "renamed file" : "bestand hernoemd",
    "Invalid parent path" : "Ongeldig bovenliggend pad",
    "File already exists" : "Bestand bestaat al",
    "Invalid path" : "Ongeldig pad",
    "Failed to create file from template" : "Kon geen bestand van het sjabloon maken",
    "Templates" : "Sjablonen",
    "Path contains invalid segments" : "Pad bevat ongeldige segmenten",
    "Filename contains at least one invalid character" : "De bestandsnaam bevat ten minste één ongeldig teken",
    "Empty filename is not allowed" : "Een lege bestandsnaam is niet toegestaan",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" kan niet worden geïnstalleerd, omdat het app info bestand niet gelezen kan worden.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "App \"%s\" kan niet worden geïnstalleerd, omdat deze niet compatible is met deze versie van de server.",
    "__language_name__" : "Nederlands",
    "This is an automatically sent email, please do not reply." : "Dit is een automatisch gegenereerde e-mail, dus reageren is niet mogelijk.",
    "Appearance and accessibility" : "Weergave en toegankelijkheid",
    "Apps" : "Apps",
    "Personal settings" : "Persoonlijke instellingen",
    "Administration settings" : "Beheerder instellingen",
    "Settings" : "Instellingen",
    "Log out" : "Uitloggen",
    "Accounts" : "Accounts",
    "Email" : "E-mail",
    "Mail %s" : "Mail %s",
    "Phone" : "Telefoon",
    "Call %s" : "Bel %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Bekijk %s op Twitter",
    "Website" : "Website",
    "Visit %s" : "Bezoek %s",
    "Address" : "Adres",
    "Profile picture" : "Profielafbeelding",
    "About" : "Over",
    "Display name" : "Weergave naam",
    "Headline" : "Hoofdlijn",
    "Organization" : "Organisatie",
    "Role" : "Rol",
    "Additional settings" : "Aanvullende instellingen",
    "You need to enter details of an existing account." : "Geef de details van een bestaand account op.",
    "Oracle connection could not be established" : "Er kon geen verbinding met Oracle worden gemaakt.",
    "For the best results, please consider using a GNU/Linux server instead." : "Voor het beste resultaat adviseren wij het gebruik van een GNU/Linux server.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Het lijkt erop dat deze %s versie draait in een 32 bits PHP omgeving en dat open_basedir is geconfigureerd in php.ini. Dat zal leiden tot problemen met bestanden groter dan 4 GB en wordt dus sterk afgeraden.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Verwijder de open_basedir instelling in php.ini of schakel over op de 64bit PHP.",
    "Set an admin password." : "Stel een beheerders wachtwoord in.",
    "Cannot create or write into the data directory %s" : "Kan niets creëren of wegschrijven in de datadirectory %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "De gedeelde achtergrond %s moet de OCP\\Share_Backend interface implementeren",
    "Sharing backend %s not found" : "De gedeelde backend %s is niet gevonden",
    "Sharing backend for %s not found" : "De gedeelde backend voor %s is niet gevonden",
    "%1$s shared %2$s with you" : "%1$s deelde %2$s met jou",
    "Open %s" : "%s openen",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s deelde %2$s met jou en wil toevoegen:",
    "%1$s shared %2$s with you and wants to add" : "%1$s deelde %2$s met jou en wil toevoegen",
    "%s added a note to a file shared with you" : "%s heeft een notitie toegevoegd aan een bestand dat met jou werd gedeeld",
    "Unknown share type" : "Onbekend type gedeelde folder",
    "You are not allowed to share %s" : "Je bent niet bevoegd om %s te delen",
    "Cannot increase permissions of %s" : "Kan de machtiging van %s niet verhogen.",
    "Files cannot be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijdermachtigingen",
    "Files cannot be shared with create permissions" : "Bestanden kunnen niet worden gedeeld met creëermachtigingen",
    "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan de vervaldatum niet meer dan %s dag in de toekomst instellen","Kan de vervaldatum niet meer dan %s dagen in de toekomst instellen"],
    "Sharing is only allowed with group members" : "Delen kan alleen met groepsleden",
    "Sharing %s failed, because this item is already shared with the account %s" : "Het delen van%s is mislukt, omdat dit item al gedeeld wordt met het account %s",
    "The requested share does not exist anymore" : "De toegang tot de gedeelde folder bestaat niet meer",
    "Could not find category \"%s\"" : "Kan categorie \"%s\" niet vinden",
    "Sunday" : "Zondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrijdag",
    "Saturday" : "Zaterdag",
    "Sun." : "Zo.",
    "Mon." : "Ma.",
    "Tue." : "Di.",
    "Wed." : "Wo.",
    "Thu." : "Do.",
    "Fri." : "Vr.",
    "Sat." : "Za.",
    "Su" : "Zo",
    "Mo" : "Ma",
    "Tu" : "Di",
    "We" : "Wo",
    "Th" : "Do",
    "Fr" : "Vr",
    "Sa" : "Za",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Maart",
    "April" : "April",
    "May" : "Mei",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mrt.",
    "Apr." : "Apr.",
    "May." : "Mei",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
    "Login canceled by app" : "Inloggen geannuleerd door app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld: %2$s",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "Application is not enabled" : "De applicatie is niet ingeschakeld",
    "Authentication error" : "Authenticatiefout",
    "Token expired. Please reload page." : "Token verlopen.  Herlaad de pagina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Geen database drivers (sqlite, mysql of postgres) geïnstalleerd.",
    "Cannot write into \"config\" directory." : "Kan niet schrijven naar de \"config\" directory!",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dit kan opgelost worden door de config map op de webserver schrijf rechten te geven. Zie %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Of, als je liever config.php Alleen-lezen houdt, stel de optie  \"config_is_read_only\" in op true. Zie %s",
    "Cannot create \"data\" directory." : "Kan de \"data\"-map niet aanmaken.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dit kan hersteld worden door de root map schrijf rechten te geven op de webserver. Zie %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Machtigingen kunnen worden hersteld door de root map op de webserver schrijf toegang te geven. Zie %s.",
    "Your data directory is not writable." : "Je datamap is niet beschrijfbaar",
    "Setting locale to %s failed." : "Instellen taal op %s mislukte.",
    "Please install one of these locales on your system and restart your web server." : "Installeer één van de talen op je systeem en herstart je webserver.",
    "PHP module %s not installed." : "PHP module %s niet geïnstalleerd.",
    "Please ask your server administrator to install the module." : "Vraag je beheerder om de module te installeren.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP instelling \"%s\" staat niet op \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Het aanpassen van deze instelling in php.ini zorgt ervoor dat Nextcloud weer start",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is nu zo ingesteld dat 'inline doc blocks' worden gestript. Hierdoor worden verschillende hoofd modules onbruikbaar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar ze worden nog steeds als ontbrekend aangegeven?",
    "Please ask your server administrator to restart the web server." : "Vraag je beheerder de webserver opnieuw te starten.",
    "Your data directory must be an absolute path." : "Je datamap moet een absolute bestandslocatie hebben.",
    "Check the value of \"datadirectory\" in your configuration." : "Controleer de waarde van \"datadirectory\" in je configuratie.",
    "Your data directory is invalid." : "Je datamap is ongeldig.",
    "Action \"%s\" not supported or implemented." : "Actie \"%s\" niet ondersteund of geïmplementeerd.",
    "Authentication failed, wrong token or provider ID given" : "Authenticatie mislukt, ongeldig token of provider ID opgegeven",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Er ontbreken parameters om de aanvraag uit te voeren. Ontbrekende parameters: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" wordt al gebruikt door cloud federatieprovider \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federationprovider met ID: \"%s\" bestaat niet.",
    "Could not obtain lock type %d on \"%s\"." : "Kon geen lock type %d krijgen op \"%s\".",
    "Storage unauthorized. %s" : "Opslag niet toegestaan. %s",
    "Storage incomplete configuration. %s" : "Incomplete opslag configuratie. %s",
    "Storage connection error. %s" : "Opslag verbindingsfout. %s",
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage connection timeout. %s" : "Opslag verbinding time-out. %s",
    "Images" : "Afbeeldingen",
    "Question" : "Vraag",
    "Confirmation" : "Bevestiging",
    "Text" : "Tekst",
    "Summary" : "Samenvatting",
    "Translate" : "Vertaal",
    "Result" : "Resultaat",
    "Organisation" : "Organisatie",
    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
    "Cannot write into \"apps\" directory." : "Kan niet schrijven naar de \"apps\" directory",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is ingesteld op <code>%s</code> in plaats van de verwachte waarde <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Om dit op te lossen stel je <code>mbstring.func_overload</code> in op <code>0</code> in je php.ini."
},
"nplurals=2; plural=(n != 1);");
